@@ -36,7 +36,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#if defined(_MSC_VER) && (defined(WIN32) || defined(_Windows) || \
+    defined(_WINDOWS) || defined(_WIN32) || defined(__WIN32__))
 #include <malloc.h>
+#endif
 #include "jpeg.h"
 #include "mcu.h"
 #include "io.h"
